#Topsis-HEMAKSHI-101903145
Multiple criteria decision making (MCDM) using TOPSIS

## Installation
```pip install topsis-HEMAKSHI-101903145```

##Sample Use case
import topsis-HEMAKSHI-10903145 as t
t.topsis("input.csv","1,2,1,2,3","+,+,-,+,-","output.csv")
